#!/bin/sh
LOG="/_config/update/update.log"
URL_MAIN="www.htpc-forum.de/gen2vdr/1.1/fixes"
URL_TEST="www.htpc-forum.de/test/1.1/fixes"
URL=""

MD5_FILE="g2v_md5_fixes"

if [ "$1" = "--help" ] ; then
   echo "Syntax: $0 [-media|-l|-f|-x]"
   echo "       -media searches for updates on a disc/USB"
   echo "       -t     searches for updates on the test server"
   echo "       -f     forces the execution of all update scripts"
   echo "       -x     forces the extraction of all update packages"
   echo ""
   echo "!!! Be careful when using -f or -t !!!"
   exit
fi   
   
cd /_config/update

if [ "$1" = "-media" ] ; then
   MEDIA_MD5=$(find /media -name $MD5_FILE -type f)
   [ "$MEDIA_MD5" == "" ] && echo "$MD5_FILE nicht vorhanden" && exit 1
   rm -f $MD5_FILE >/dev/null 2>&1
   MEDIA_PATH=$(dirname $MEDIA_MD5)
   cp -f "$MEDIA_MD5" .
elif [ "$1" != "-f" -a "$1" != "-x" ] ; then
   if [ "$1" = "-t" ] ; then
      URL=$URL_TEST
   else
      URL=$URL_MAIN
   fi            
   rm -f $MD5_FILE >/dev/null 2>&1
   wget "${URL}/${MD5_FILE}"
fi
ARCHS=$(grep "\.tar\.bz2" $MD5_FILE | cut -f 3 -d " ")

for i in $ARCHS ; do
   [ "$i" = "g2v_cdupdate.tar.bz2" ] && continue
   if [ "$(grep "$i" .blacklist 2> /dev/null)" = "$i" ] ; then
      echo "<$i> ist auf der schwarzen Liste"
      continue
   fi
   if [ -f ${i} -a "$1" != "-f" ] ; then
      echo "Checking md5sum <${i}> ..."
      MD5=$(md5sum ${i} | cut -f 1 -d " ")
      if [ "$(grep ${i} ${MD5_FILE} | grep $MD5)" != "" ] ; then
         if [ "$URL" != "" ];  then
            echo "$i bereits verarbeitet"
	    continue
         fi
      else
         if [ "$URL" != "" ];  then
            rm -f ${i}
         else
	    echo "$i ist fehlerhaft"
	    continue
	 fi	    
      fi    
   else 
      if [ "$1" = "-x" ] ; then
         echo "$i ist nicht vorhanden"
	 continue
      fi	 
   fi
   if [ ! -f ${i} -a "$1" != "-f" ] ; then
      if [ "$URL" != "" ] ; then
         echo "Downloading <${i}> ..." | tee -a $LOG
         wget ${URL}/${i}
      else
         if [ "$1" = "-media" ] ; then
            cp -f $MEDIA_PATH/$i /_config/update/
	 fi      
      fi   
      MD5=$(md5sum ${i} | cut -f 1 -d " ")
      if [ "$(grep ${i} ${MD5_FILE} | grep $MD5)" = "" ] ; then
         logger -s "Fehler bei Download/Kopieren von ${i}"
         exit -1
      fi
   fi 
   if [ "$i" != "-f" ] ; then     
      logger -s "Entpacke <$i>"            
      tar -C / -xjvf $i 2>&1 | tee -a $LOG
   fi      
   INST_SCRIPT=$(echo $i| sed -e "s/.tar.bz2/.sh/")
   if [ -f $INST_SCRIPT -a "$1" != "-x" ] ; then
      logger -s "Starte <$INST_SCRIPT>"            
      sh $INST_SCRIPT 2>&1 | tee -a $LOG
   fi
done
if [ "$(pidof vdr)" = "" ] ; then
   /etc/init.d/vdr start
fi

